//*****************************************************************************
//  MSP430 DIr169 Demo - DMA0 Repeated Block To UART1, CCR2IFG Trigger
//
//  Description; DMA0 is used to transfer a string byte-by-byte as a repeating
//  block to U1TXBUF. Timer_A operates continuously at 32768Hz with CCR2IFG 
//  triggering DMA0. "MSP430 ATC 2003" is TX'd via 9600 baud UART1.
//  ACLK= TACLK 32768Hz, MCLK= SMCLK= default DCO ~ 800k
//
//               MSP430F169
//            -----------------
//        /|\|              XIN|-  
//         | |                 | 32768Hz
//         --|RST          XOUT|-
//           |                 |
//           |             P3.6|--> UTXD1
//
//  Z. Albus
//  Texas Instruments, Inc
//  October 2003
//  Built with IAR Embedded Workbench Version: 3.0B
//*****************************************************************************

#include  <msp430x16x.h>

const unsigned char UART_Data[] = {"MSP430 ATC 2003\r\n"};

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                   // Stop watchdog
  P1DIR = 0xCB;                               // Init P1.x
  P1OUT = 0x08;                               // 
  P2DIR = 0xFF;                               // Init P2.x
  P2OUT = 0x00;                               // 
  P3SEL |= 0x40;                              // P3.6 = USART1 TXD
  P3DIR = 0x75;                               // Init P3.x
  P3OUT = 0x00;                               // 
  P4DIR = 0xFF;                               // Init P4.x
  P4OUT = 0x00;                               // 
  P5DIR = 0xFF;                               // Init P5.x
  P5OUT = 0x00;                               // 
  P6SEL |= 0x01;                              // P6.0 = analog input
  P6DIR = 0xFE;                               // Init P6.x
  P6OUT = 0x00;                               // 

  ME2 |= UTXE1;                               // Enabled UART1 TXD
  UCTL1 |= CHAR;                              // 8-bit char, SWRST=1
  UTCTL1 |= SSEL0;                            // UCLK = ACLK
  UBR01 = 0x03;                               // 9600 from 32768Hz
  UBR11 = 0x00;
  UMCTL1 = 0x4A;                              // Modulation
  UCTL1 &= ~SWRST;                            // Enable USART

  DMACTL0 = DMA0TSEL_1;                       // 0-CCR2IFG
  DMA0SA = (unsigned int)UART_Data;           // Source block address
  DMA0DA = U1TXBUF_;                          // Dest single address
  DMA0SZ = sizeof UART_Data-1;                // Block size
  DMA0CTL = DMADT_4 + DMASRCINCR_3 + DMASBDB + DMAEN;// Rpt, inc src, enable

  TACTL = TASSEL_1 + MC_1;                    // ACLK, up-mode
  TACCR0 = 8192;                              // Char freq = TACLK/CCR0
  TACCR2 = 1;                                 // For DMA0 trigger
        
  _BIS_SR(LPM3_bits);                         // Enter LPM3
}
