//******************************************************************************
// MSP430 DIr169 I2C Demo - HW Slave: I2C clock wake-up
//
// Description; The slave 'F169 communicates via I2C with the master which
// requests two bytes once every second. The slave address is 0x48. When data
// is requested by the master, the slave (normally in LPM4) starts the I2C clock
// source and transmits the data in ADC12MEM0. Another conversion of the
// temperature sensor is triggered before exiting the I2C ISR.
// Default DCO ~= 800kHz = MCLK = SMCLK = I2CCLK
//
//             MSP430F169 SLAVE
//             -----------------
//         /|\|              XIN|-  
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |            P3.1 |<---> I2C SDA
//            |            P3.3 |<---- I2C SCL
//
//
//  Z. Albus
//  Texas Instruments, Inc
//  October 2003
//  Built with IAR Embedded Workbench Version: 3.0B
//******************************************************************************

#include  "msp430x16x.h"

void main (void)
{
  WDTCTL = WDTPW + WDTHOLD;                   // Stop WDT
  P1DIR = 0xCB;                               // Init P1.x
  P1OUT = 0x08;                               // 
  P2DIR = 0xFF;                               // Init P2.x
  P2OUT = 0x00;                               // 
  P3SEL |= 0x0A;                              // Select I2C pins
  P3DIR = 0x75;                               // Init P3.x
  P3OUT = 0x00;                               // 
  P4DIR = 0xFF;                               // Init P4.x
  P4OUT = 0x00;                               // 
  P5SEL |= 0x20;                              // Output SMCLK
  P5DIR = 0xFF;                               // Init P5.x
  P5OUT = 0x00;                               // 
  P6SEL |= 0x01;                              // P6.0 = analog input
  P6DIR = 0xFE;                               // Init P6.x
  P6OUT = 0x00;                               // 

  U0CTL |= I2C + SYNC;                        // Configure for I2C mode
  U0CTL &= ~I2CEN;                            // Clear enable
  I2CTCTL |= I2CWORD + I2CSSEL1;              // Word mode, SMCLK
  I2COA = 0x0048;                             // Own Address is 048h
  I2CIE = TXRDYIE;                            // Enable TXRDYIFG
  U0CTL |= I2CEN;                             // Enable I2C
  ADC12CTL0 = ADC12ON + SHT0_6;               // Turn on ADC12, set SHT0
                                              // for longer sampling required
                                              // by temp diode.
  ADC12CTL1 = SHP;                            // Use sampling timer
  ADC12MCTL0 = INCH_10;                       // Select channel A10, Vcc/Vss
  ADC12CTL0 |= ENC;                           // Enable conversions
  ADC12CTL0 |= ADC12SC;                       // Trigger 1st conversion
  
  for (;;)                              
  {
    _BIS_SR(LPM4_bits + GIE);                 // Enter LPM4 with ints
  }
}

#pragma vector=USART0TX_VECTOR
__interrupt void I2C_ISR (void)
{
 switch( I2CIV )
 { //TXRDYIFG ISR
   case 12: I2CDRW = ADC12MEM0;               // Move conversion to buffer
            break;
 }
 ADC12CTL0 |= ADC12SC;                        // Trigger next conversion
}
