//******************************************************************************
// MSP430 DIr169 I2C Demo - HW Master
//
// Description; The master 'F169 communicates via I2C requesting two bytes from
// the slave at address 0x48 once every 2 seconds. Each new value is compared to
// the last and LEDs on P1.0 and P1.1 are set/cleared accordingly.
// SCL ~= 80kHz based on the default DCO ~= 800kHz, ACLK = 32768Hz
//
//               MSP430F169 MASTER
//               -----------------
//           /|\|              XIN|-  
//            | |                 | 32,768 Hz
//            --|RST          XOUT|-
//              |                 |
//   Heating <--|P1.0        P3.1 |<---> I2C SDA
//   Cooling <--|P1.1        P3.3 |----> I2C SCL
//
//
//  Z. Albus
//  Texas Instruments, Inc
//  October 2003
//  Built with IAR Embedded Workbench Version: 3.0B
//******************************************************************************

#include  "msp430x16x.h"

unsigned int RXData,RXData_old;

void main (void)
{
  WDTCTL = WDT_ADLY_1000;                     // WDT 1s interval timer
  BCSCTL1 |= DIVA0;                           // ACLK/2
  IE1 |= WDTIE;                               // Enable WDT interrupt
  
  P1DIR = 0xCB;                               // Init P1.x
  P1OUT = 0x08;                               // 
  P2DIR = 0xFF;                               // Init P2.x
  P2OUT = 0x00;                               // 
  P3SEL |= 0x0A;                              // Select I2C pins
  P3DIR = 0x75;                               // Init P3.x
  P3OUT = 0x00;                               // 
  P4DIR = 0xFF;                               // Init P4.x
  P4OUT = 0x00;                               // 
  P5DIR = 0xFF;                               // Init P5.x
  P5OUT = 0x00;                               // 
  P6SEL |= 0x01;                              // P6.0 = analog input
  P6DIR = 0xFE;                               // Init P6.x
  P6OUT = 0x00;                               // 

  U0CTL |= I2C + SYNC;                        // Recommended init procedure
  U0CTL &= ~I2CEN;                            // Recommended init procedure
  I2CTCTL |= I2CWORD + I2CSSEL1;              // Word mode, SMCLK
  I2CNDAT = 0x02;                             // Read one word: two bytes
  I2CSA = 0x0048;                             // Slave Address is 048h
  I2CIE = RXRDYIE;                            // Enable RXRDYIFG interrupt
  U0CTL |= I2CEN;                             // Enable I2C

  while(1)
  { 
    _BIS_SR(LPM0_bits + GIE);                 // Enter LPM0 with ints
  }
}

#pragma vector=USART0TX_VECTOR
__interrupt void I2C_ISR (void)
{
  switch(I2CIV)
  {
    case 10:                                  // Receive Ready
             RXData = I2CDRW;                 // Handle data from slave
             break; 
 }
}

#pragma vector=WDT_VECTOR
__interrupt void watchdog_timer (void)
{
    if (RXData > RXData_old+1)                // Warmer: LED0 = ON
    {
      P1OUT |=0x01;
      P1OUT &=~0x02;
    }
    else if (RXData < RXData_old-1)           // Cooler: LED1 = ON
    {
      P1OUT &=~0x01;
      P1OUT |=0x02;
    }
    else
      P1OUT &=~0x03;
    
    RXData_old = RXData;
    U0CTL |= MST;                             // Master mode
    I2CTCTL |= I2CSTT + I2CSTP;               // Initiate transfer
}
