//*******************************************************************************
//  MSP430 DIr169 LPM3 Demo - Software Toggle P1.0 & P1.1
//
//  Description; Toggle P1.0,1.1 by xor'ing inside of WDT ISR. WDT INT exits LPM3
//  on a 4 second interval to turn the LEDs on, and a 7.8ms interval to turn the
//  LEDs off. Normally in LPM3.
//  ACLK = 32.768kHz, MCLK = SMCLK = default DCO ~ 800k
//
//                MSP430F169
//             -----------------
//         /|\|              XIN|-  
//          | |                 | 32,768 Hz
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED
//            |                 |
//            |             P1.1|-->LED
//
//  Z. Albus
//  Texas Instruments, Inc
//  October 2003
//  Built with IAR Embedded Workbench Version: 3.0B
//******************************************************************************

#include <msp430x16x.h>

void main(void)
{ 
  WDTCTL = WDT_ADLY_1000;                     // WDT 1s*4 interval timer
  BCSCTL1 |= DIVA1;                           // ACLK/4
  IE1 |= WDTIE;                               // Enable WDT interrupt
  P1DIR = 0xCB;                               // Init P1.x
  P1OUT = 0x08;                               // 
  P2DIR = 0xFF;                               // Init P2.x
  P2OUT = 0x00;                               // 
  P3DIR = 0x75;                               // Init P3.x
  P3OUT = 0x00;                               // 
  P4DIR = 0xFF;                               // Init P4.x
  P4OUT = 0x00;                               // 
  P5DIR = 0xFF;                               // Init P5.x
  P5OUT = 0x00;                               // 
  P6SEL |= 0x01;                              // P6.0 = analog input
  P6DIR = 0xFE;                               // Init P6.x
  P6OUT = 0x00;                               // 
 
  while(1)
  {
    _BIS_SR(LPM3_bits + GIE);                 // Enter LPM3 with ints
  }
}

#pragma vector=WDT_VECTOR
__interrupt void watchdog_timer (void)
{
    if ((P1OUT & 0x01) == 0x01)
    {
      WDTCTL = WDT_ADLY_1000;                 // WDT 1s*4 interval timer
      P1OUT &= ~0x03;                         // Clear P1.0,1.1 LEDs
    }  
    else
    {
      WDTCTL = WDT_ADLY_1_9;                  // WDT 1.9ms*4 interval timer
      P1OUT |= 0x03;                          // Set P1.0,1.1 LEDs
    }
}

