//******************************************************************************
// MSP430 DIr169 TBIV Demo - Toggle LEDs using TBIV
//
// Description; Timer_B CCR1 and CCR2 are used to toggle P1.0 and P1.1,
// respectively. P1.0 flashes twice each second. Toggle frequency for P1.1 is 2
// times P1.0.
// Default DCO ~= 800kHz = MCLK = SMCLK, ACLK = TBCLK = 32768Hz
//
//             MSP430F169 SLAVE
//             -----------------
//         /|\|              XIN|-  
//          | |                 | 32768Hz
//          --|RST          XOUT|-
//            |                 |
//            |            P1.0 |---> LED0
//            |            P1.1 |---> LED1
//
//
//  Z. Albus
//  Texas Instruments, Inc
//  October 2003
//  Built with IAR Embedded Workbench Version: 3.0B
//******************************************************************************

#include <msp430x16x.h>

void main(void)
{ 
  WDTCTL = WDTPW + WDTHOLD;                   // Stop WDT  
  P1DIR = 0xCB;                               // Init P1.x
  P1OUT = 0x08;                               // 
  P2DIR = 0xFF;                               // Init P2.x
  P2OUT = 0x00;                               // 
  P3DIR = 0x75;                               // Init P3.x
  P3OUT = 0x00;                               // 
  P4DIR = 0xFF;                               // Init P4.x
  P4OUT = 0x00;                               // 
  P5DIR = 0xFF;                               // Init P5.x
  P5OUT = 0x00;                               // 
  P6SEL |= 0x01;                              // P6.0 = analog input
  P6DIR = 0xFE;                               // Init P6.x
  P6OUT = 0x00;                               // 
  
  TBCTL = TBSSEL0 + TBCLR;                    // ACLK, clear TBR
  TBCCTL1 = CCIE;                             // TRCCR1 interrupt enabled
  TBCCTL2 = CCIE;                             // TRCCR2 interrupt enabled
  TBCCR1 = 8192;
  TBCCR2 = 4096;
  TBCTL |= MC1;                               // Start Timer_B in continuous mode
 
  for (;;)                              
  {
    _BIS_SR(LPM3_bits + GIE);                 // Enter LPM3 with ints
  }
}

// Timer_B7 Interrupt Vector (TBIV) handler
#pragma vector=TIMERB1_VECTOR
__interrupt void Timer_B_IV(void)
{
 switch( TBIV )
 {
   case  2: P1OUT ^= 0x01;                    // CCR1 toggle P1.0
            TBCCR1 += 8192;
            break;
   case  4: P1OUT ^= 0x02;                    // CCR2 toggle P1.1
            TBCCR2 += 4096;
            break;
  }
}
