//******************************************************************************
//  Dir169 Demo - USART1 UART 9600 Transmit, 32kHz ACLK
//
//  Description; Transmit the string "MSP430 ATC 2003" using USART1. The Mainloop
//  waits in LPM3. The WDT ISR at 1s intervals initiates the block transfer. 
//  The USART TX ready ISR will advance tranmit through the string.
//  ACLK = UCLK1 = LFXT1 = 32768, MCLK = SMCLK = DCO~ 800k  
//  Baud rate divider with 32768hz XTAL @9600 = 32768Hz/9600 = 3.41 (000Dh 4Ah )
// //*An external watch crystal is required on XIN XOUT for ACLK*//	  
//
//                  DIr169
//             -----------------
//         /|\|              XIN|-  
//          | |                 | 32kHz
//          --|RST          XOUT|-
//            |                 |
//            |             P3.4|------------> "MSP430 ATC 2003"
//            |                 | 9600 - 8N1
//
//  M.Buccini
//  Texas Instruments, Inc
//  November 2003
//  Built with IAR Embedded Workbench Version: 2.20A
//******************************************************************************

#include  "msp430x16x.h"

static char string1[] = { "MSP430 ATC 2003\r\n" };

char i;

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;             // Stop watchdog
  P3SEL = 0xC0;                         // P3.6,7 = USART1 TXD/RXD

  ME2 |= UTXE1 + URXE1;                 // Enabled USART1 TXD/RXD
  UCTL1 |= CHAR;                        // 8-bit character, SWRST=1
  UTCTL1 |= SSEL0;                      // UCLK = ACLK
  UBR01 = 0x03;                         // 9600 from 1Mhz
  UBR11 = 0x00;                         //
  UMCTL1 = 0x4A;                        // Modulation
  UCTL1 &= ~SWRST;                      // Initialize USART state machine
  IE2 |= UTXIE1;                        // Enable USART1 TX interrupt
  WDTCTL = WDT_ADLY_1000;               // WDT 1000ms, ACLK, interval timer
  IE1 |= WDTIE;                         // Enable WDT interrupt
     
  _BIS_SR(LPM3_bits + GIE);             // Enter LPM3 w/ interrupt
}

// UART1 TX ISR 
#pragma vector=UART1TX_VECTOR
__interrupt void usart1_tx (void)
{
  if (i < sizeof string1-1)
 {
    TXBUF1 = string1[i];                      
    i++;
  }
}

// Watchdog Timer interrupt service routine
#pragma vector=WDT_VECTOR
__interrupt void watchdog_timer(void)
{
    i = 0; 
    TXBUF1 = string1[i];                      
    i++;
}


